% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/analyse_model.R
\name{analyse_model}
\alias{analyse_model}
\title{Analyse a model.}
\usage{
analyse_model(
  model,
  type = "",
  stage = "",
  hazard_range = getOption("floodam_building_hazard_range"),
  path = getOption("floodam_building_path"),
  file_name = getOption("floodam_building_file_name"),
  type_building = getOption("floodam_building_type_building"),
  version_building = NULL,
  verbose = getOption("floodam_building_verbose"),
  dam_by_room = FALSE
)
}
\arguments{
\item{model}{either a character, name given to the model or an object of class model}

\item{type}{character, type of model that is loaded, default to ""}

\item{stage}{character, what are the stages that should be done, default to nothing}

\item{hazard_range}{if damaging are calculated, gives the range for hazard, default to getOption("floodam_building_hazard_range")}

\item{path}{list of useful paths, default to getOption("floodam_building_path")}

\item{file_name, }{list of useful file names, default to getOption("floodam_building_file_name")}

\item{type_building}{character, type of building file (building or yaml)}

\item{version_building}{character, version of building model to be used}

\item{verbose}{boolean, will floodam tells what it is doing, default to getOption("floodam_building_verbose")}

\item{dam_by_room}{logical. Should the damage functions be computed by room? Default to FALSE}
}
\value{
an object of class model
}
\description{
Analyse a model.
}
\examples{

# Example 1
# declaring input and output paths
	model_path = list(
		data = system.file("extdata", package = "floodam.building"),
		output = tempdir()
	)

# analyzing model 'adu_t' of type 'adu' using the sequential steps *load* 
# (load model data), *extract* (extract model data) and *damaging* (calculate 
# damage function)
	analyse_model(
		model = "adu_t", 
		type = "adu", 
		stage = c("load", "extract", "damaging"), 
		path = model_path
	)

# Example 2
# using already loaded library model 'dwelling' 
model = dwelling

# extracting model data
model = analyse_model(model = model, stage = "extract")

# calculating damage function
model = analyse_model(model = model, stage = "damaging")

# calculating hydraulic inputs
model = analyse_model(model = model, stage = "hydraulic")

}
